@@ -695,9 +695,16 @@ object RClient {
         ${codeInR}
         environment()
       })"""
+    val sourceFile = File.createTempFile("rscala-","")
+    val sourceFileNameForR = sourceFile.getAbsolutePath.replace(File.separator,"/")
+    val writer = new FileWriter(sourceFile)
+    writer.write(allCodeInR)
+    writer.flush()
+    writer.close()
     val portsFile = File.createTempFile("rscala-","")
     val snippet = s"""
-      ${allCodeInR}
+      source("${sourceFileNameForR}")
+      file.remove("${sourceFileNameForR}")
       rscala[['rServe']](rscala[['newSockets']]('${portsFile.getAbsolutePath.replace(File.separator,"/")}',debug=${if ( debug ) "TRUE" else "FALSE"},timeout=${timeout}))
       q(save='no')
     """.stripMargin
